@@ -90,7 +90,7 @@ func (c *Crawler) navigateRequest(ctx context.Context, httpclient *retryablehttp
 	page = page.Timeout(timeout)
 
 	// wait the page to be fully loaded and becoming idle
-	waitNavigation := page.WaitNavigation(proto.PageLifecycleEventNameDOMContentLoaded)
+	waitNavigation := page.WaitNavigation(proto.PageLifecycleEventNameFirstMeaningfulPaint)
 
 	if err := page.Navigate(request.URL); err != nil {
 		return nil, errors.Wrap(err, "could not navigate target")
