@@ -7,6 +7,7 @@ import (
 
 	"github.com/PuerkitoBio/goquery"
 	"github.com/projectdiscovery/katana/pkg/navigation"
+	"github.com/projectdiscovery/katana/pkg/output"
 	"github.com/projectdiscovery/katana/pkg/utils"
 	"golang.org/x/net/html"
 )
@@ -68,6 +69,9 @@ var responseParsers = []responseParser{
 	// Optional JS relative endpoints parsers
 	{contentParser, scriptJSFileRegexParser},
 	{contentParser, bodyScrapeEndpointsParser},
+
+	// custom field regex parser
+	{bodyParser, customFieldRegexParser},
 }
 
 // parseResponse runs the response parsers on the navigation response
@@ -486,6 +490,11 @@ func bodyFormTagParser(resp navigation.Response, callback func(navigation.Reques
 			return
 		}
 
+		parsedURL, err := url.Parse(actionURL)
+		if err != nil {
+			return
+		}
+
 		isMultipartForm := strings.HasPrefix(encType, "multipart/")
 
 		queryValuesWriter := make(url.Values)
@@ -537,12 +546,8 @@ func bodyFormTagParser(resp navigation.Response, callback func(navigation.Reques
 		}
 		switch method {
 		case "GET":
-			value := queryValuesWriter.Encode()
-			sb.Reset()
-			sb.WriteString(req.URL)
-			sb.WriteString("?")
-			sb.WriteString(value)
-			req.URL = sb.String()
+			parsedURL.RawQuery = queryValuesWriter.Encode()
+			req.URL = parsedURL.String()
 		case "POST":
 			if multipartWriter != nil {
 				req.Body = sb.String()
@@ -621,3 +626,47 @@ func bodyScrapeEndpointsParser(resp navigation.Response, callback func(navigatio
 		callback(navigation.NewNavigationRequestURLFromResponse(item, resp.Resp.Request.URL.String(), "html", "regex", resp))
 	}
 }
+
+// customFieldRegexParser parses custom regex from HTML body and header
+func customFieldRegexParser(resp navigation.Response, callback func(navigation.Request)) {
+	var customField = make(map[string][]string)
+	for _, v := range output.CustomFieldsMap {
+		results := []string{}
+		for _, re := range v.CompileRegex {
+			matches := [][]string{}
+
+			// read body
+			if v.Part == output.Body.ToString() || v.Part == output.Response.ToString() {
+				matches = re.FindAllStringSubmatch(string(resp.Body), -1)
+			}
+
+			// read header
+			if v.Part == output.Header.ToString() || v.Part == output.Response.ToString() {
+				for key, v := range resp.Resp.Header {
+					header := key + ": " + strings.Join(v, "\n")
+					headerMatches := re.FindAllStringSubmatch(header, -1)
+					matches = append(matches, headerMatches...)
+				}
+			}
+
+			for _, match := range matches {
+				if len(match) < (v.Group + 1) {
+					continue
+				}
+				matchString := match[v.Group]
+				results = append(results, matchString)
+			}
+		}
+		if len(results) > 0 {
+			customField[v.GetName()] = results
+		}
+	}
+	if len(customField) != 0 {
+		callback(navigation.Request{
+			Method:       "GET",
+			URL:          resp.Resp.Request.URL.String(),
+			Depth:        resp.Depth,
+			CustomFields: customField,
+		})
+	}
+}
