@@ -3,11 +3,13 @@ package parser
 import (
 	"net/http"
 	"net/url"
+	"regexp"
 	"strings"
 	"testing"
 
 	"github.com/PuerkitoBio/goquery"
 	"github.com/projectdiscovery/katana/pkg/navigation"
+	"github.com/projectdiscovery/katana/pkg/output"
 	"github.com/projectdiscovery/katana/pkg/types"
 	"github.com/stretchr/testify/require"
 )
@@ -539,3 +541,88 @@ func TestScriptParsers(t *testing.T) {
 
 	})
 }
+
+func TestRegexBodyParsers(t *testing.T) {
+	parsed, _ := url.Parse("https://security-crawl-maze.app/contact")
+	t.Run("regexbody", func(t *testing.T) {
+		output.CustomFieldsMap = make(map[string]output.CustomFieldConfig)
+		resp := navigation.Response{
+			Resp:  &http.Response{Request: &http.Request{URL: parsed}},
+			Depth: 0,
+			Body:  []byte("some content contact@example.com"),
+		}
+
+		// set required regex
+		output.CustomFieldsMap["email"] = output.CustomFieldConfig{
+			Name:         "email",
+			Type:         "regex",
+			Part:         "body",
+			CompileRegex: []*regexp.Regexp{regexp.MustCompile(`([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+\.[a-zA-Z0-9_-]+)`)},
+		}
+
+		var gotFields map[string][]string
+		customFieldRegexParser(resp, func(resp navigation.Request) {
+			gotFields = resp.CustomFields
+		})
+		var requireFields = map[string][]string{"email": {"contact@example.com"}}
+		require.Equal(t, requireFields, gotFields, "could not get correct url")
+	})
+	t.Run("regexheader", func(t *testing.T) {
+		output.CustomFieldsMap = make(map[string]output.CustomFieldConfig)
+		resp := navigation.Response{
+			Resp: &http.Response{Request: &http.Request{URL: parsed},
+				Header: http.Header{
+					"server": []string{"ECS (dcb/7F84)"},
+				},
+			},
+		}
+
+		// set required regex
+		output.CustomFieldsMap["server"] = output.CustomFieldConfig{
+			Name:         "server",
+			Type:         "regex",
+			Part:         "header",
+			CompileRegex: []*regexp.Regexp{regexp.MustCompile(`server: ECS`)},
+		}
+
+		var gotFields map[string][]string
+		customFieldRegexParser(resp, func(resp navigation.Request) {
+			gotFields = resp.CustomFields
+		})
+		var requireFields = map[string][]string{"server": {"server: ECS"}}
+		require.Equal(t, requireFields, gotFields, "could not get correct url")
+	})
+
+	t.Run("regexresponse", func(t *testing.T) {
+		output.CustomFieldsMap = make(map[string]output.CustomFieldConfig)
+		resp := navigation.Response{
+			Resp: &http.Response{Request: &http.Request{URL: parsed},
+				Header: http.Header{
+					"server": []string{"ECS (dcb/7F84)"},
+				},
+			},
+			Body: []byte("some content contact@example.com"),
+		}
+
+		// set required regex
+		output.CustomFieldsMap["server"] = output.CustomFieldConfig{
+			Name:         "server",
+			Type:         "regex",
+			Part:         "response",
+			CompileRegex: []*regexp.Regexp{regexp.MustCompile(`ECS`)},
+		}
+		output.CustomFieldsMap["email"] = output.CustomFieldConfig{
+			Name:         "email",
+			Type:         "regex",
+			Part:         "response",
+			CompileRegex: []*regexp.Regexp{regexp.MustCompile(`([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+\.[a-zA-Z0-9_-]+)`)},
+		}
+
+		var gotFields map[string][]string
+		customFieldRegexParser(resp, func(resp navigation.Request) {
+			gotFields = resp.CustomFields
+		})
+		var requireFields = map[string][]string{"server": {"ECS"}, "email": {"contact@example.com"}}
+		require.Equal(t, requireFields, gotFields, "could not get correct url")
+	})
+}
